*=================== Program: PQI09_ALL_MEASURES.SAS ===========================;
*
*  DESCRIPTION:
*         Assigns the Prevention Quality Indicator 09, Low Birth Weight Rate
*       to inpatient records. 
*
*
*  USER NOTE1: The PQI09_ALL_FORMATS.SAS program must be run BEFORE
*               running this program.
*
*  USER NOTE2: The AHRQ QI software does not support the calculation of  
*              weighted estimates and standard errors using complex 
*              sampling designs. 
*
*  VERSION: SAS QI v2018 (ICD-10 CM/PCS)
*  RELEASE DATE: JUNE 2018
* ============================================================================;
*PATHNAME specifies the location of the PQI09 folder which includes 
          Programs, SASdata, and Macros subfolders;
%LET PATHNAME=C:\Pathname\PQI09;                        *<==USER MUST modify;

filename CONTROL "&PATHNAME.\Programs\PQI09_ALL_CONTROL.SAS"; 

%INCLUDE CONTROL;

 title2 'PQI09_ALL_MEASUREs PROGRAM';
 title3 'AHRQ PREVENTION QUALITY INDICATORS: ASSIGN PQI 09 TO INPATIENT DATA';

 * -------------------------------------------------------------- ;
 * --- CREATE A PERMANENT DATASET CONTAINING ALL RECORDS THAT --- ; 
 * --- WILL NOT BE INCLUDED IN ANALYSIS BECAUSE KEY VARIABLE  --- ;
 * --- VALUES ARE MISSING.                                    --- ;
 * -------------------------------------------------------------- ;

 data   OUTMSR.&DELFILE.
   (keep=KEY HOSPID SEX AGE DX1 MDC YEAR DQTR);
 set INMSR.&DISCHARGE.;
 if (AGE lt 0) or (AGE ge 18 or MDC IN (14)) or (SEX le 0) or 
   (DX1 IN (' ')) or (DQTR le .Z) or (YEAR le .Z);
 run;

  *--- LOAD STANDARD DIAGNOSIS AND PROCEDURE CODE MACROS       ---* ;
 %include Maclib(PQI09_Dx_Px_Macros.sas) ;

 * ---------------------------------------------------------------- ;
 * --- PREVENTION QUALITY INDICATOR (PQI) NAMING CONVENTION:    --- ;
 * --- THE FIRST LETTER IDENTIFIES THE PREVENTION INDICATOR     --- ;
 * --- AS NUMERATOR, 'T' ("TOP"). THE SECOND LETTER IDENTIFIES  --- ;
 * --- THE TYPE OF INDICATOR WITH 'A' FOR AREA LEVEL. THE NEXT  --- ;
 * --- TWO CHARACTERS ARE 'PQ'. THE LAST TWO DIGITS ARE 09 FOR  --- ;
 * --- INDICATOR PQI 09.                                     --- ;
 * ---------------------------------------------------------------- ;

 DATA   OUTMSR.&OUTFILE_MEAS. 
    (KEEP=KEY FIPSTCO DRG MDC YEAR DQTR 
          POPCAT SEXCAT RACECAT
          TAPQ09);
 SET   INMSR.&DISCHARGE. 
      (KEEP=KEY DRG MDC SEX AGE AGEDAY PSTCO 
            RACE YEAR DQTR
            ASOURCE POINTOFORIGINUB04 ATYPE
            DX1-DX&NDX. DXPOA1-DXPOA&NDX.);
 

 * ----------------------------------------------------------------- ;
 * --- DELETE NON-PEDIATRIC RECORDS AND RECORDS WITH MISSING VALUES  ;
 * ----------------------------------------------------------------- ;
 if SEX le 0 then delete;
 if AGE lt 0 then delete;
 if AGE ge 18 or MDC IN (14) then delete;
 if DX1 IN (' ') then delete;
 if DQTR le .Z then delete;
 if YEAR le .Z then delete;

 * -------------------------------------------------------------- ;
 * --- DEFINE FIPS STATE AND COUNTY CODES ----------------------- ;
 * -------------------------------------------------------------- ;
 attrib FIPSTCO length=$5
   label='FIPS STATE COUNTY CODE';
 FIPSTCO = put(PSTCO,Z5.);


 * -------------------------------------------------------------- ;
 * --- DEFINE ICD-10-CM VERSION --------------------------------- ;
 * -------------------------------------------------------------- ;
 attrib ICDVER length=3
   label='ICD-10-CM VERSION';

 ICDVER = 0;
 if (YEAR in (2015) and DQTR in (4))          then ICDVER = 33;
 else if (YEAR in (2016) and DQTR in (1,2,3)) then ICDVER = 33;
 else if (YEAR in (2016) and DQTR in (4))     then ICDVER = 34;
 else if (YEAR in (2017) and DQTR in (1,2,3)) then ICDVER = 34;
 else if (YEAR in (2017) and DQTR in (4))     then ICDVER = 35;
 else if (YEAR in (2018) and DQTR in (1,2,3)) then ICDVER = 35;
 else ICDVER = 35; *Defaults to last version for discharges outside coding updates.; 

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: RACE CATEGORY ------------------------- ;
 * -------------------------------------------------------------- ;
 attrib RACECAT length=3
   label='PATIENT RACE/ETHNICITY';

 select (RACE);
   when (1)  RACECAT = 1;
   when (2)  RACECAT = 2;
   when (3)  RACECAT = 3;
   when (4)  RACECAT = 4;
   when (5)  RACECAT = 5;
   otherwise RACECAT = 6;
 end; 



 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: SEX CATEGORY -------------------------- ;
 * -------------------------------------------------------------- ;
 attrib SEXCAT length=3
   label='PATIENT SEX';

 select (SEX);
   when (1)  SEXCAT = 1;
   when (2)  SEXCAT = 2;
   otherwise SEXCAT = 0;
 end;


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: POPULATION CATEGORY ------------------- ;
 * -------------------------------------------------------------- ;
 attrib POPCAT length=3
   label='PATIENT AGE';

 POPCAT=put(AGE,AGEFMT.);


 * -------------------------------------------------------------- ;
 * --- DEFINE AREA LEVEL INDICATORS ----------------------------- ;
 * -------------------------------------------------------------- ;
%MACRO LBL;

 attrib
 TAPQ09 length=8
   label='PQI 09 Low Birth Weight Rate (Numerator)'
;

%MEND;

%LBL;

 
 * -------------------------------------------------------------- ;
 * --- IDENTIFY NEONATES AND NEWBORNS --------------------------- ;
 * -------------------------------------------------------------- ;

   NEONATE = 0;
   if 0 <= AGEDAY <= 28 then NEONATE = 1;
   else if AGEDAY le .Z and AGE = 0 then do;
      if ATYPE IN (4) or  %MDX($LIVEBND.)
      then NEONATE = 1;
   end;

   NEWBORN = 0;
   if NEONATE then do;
      if %MDX($LIVEBND.) and NOT AGEDAY > 0 then NEWBORN = 1;
      else if ATYPE IN (4) and 
              ((AGEDAY = 0 and NOT %MDX($LIVEB2D.)) or
               POINTOFORIGINUB04 IN ('5'))
      then NEWBORN = 1;
   end;
 

   * --- CONSTRUCT AREA LEVEL INDICATORS --- ;

   * -------------------------------------------------- ;
   * --- PQI 09 : LOW BIRTH WEIGHT                  --- ;
   * -------------------------------------------------- ;


   if NEWBORN then do;

      TAPQ09 = 0;

      if %MDX($ACSLBWD.) then TAPQ09 = 1;

   end;


 * -------------------------------------------------------------- ;
 * --- EXCLUDE TRANSFERS ---------------------------------------- ;
 * -------------------------------------------------------------- ;

 * --- TRANSFER FROM ANOTHER ---------------- ;
 if ATYPE notin (4) and
    (ASOURCE in (2,3) or POINTOFORIGINUB04 in ('4','5','6')) 
 then do;
   TAPQ09 = .;
 end;

run;


proc Contents data=OUTMSR.&OUTFILE_MEAS. position;
run;

proc Print data=OUTMSR.&OUTFILE_MEAS. (OBS=24);
title4 "FIRST 24 RECORDS IN OUTPUT DATA SET &OUTFILE_MEAS.";
run;

***---- TO PRINT VARIABLE LABELS COMMENT (DELETE) "NOLABELS" FROM PROC MEANS STATEMENTS ---***;

proc Means data = OUTMSR.&OUTFILE_MEAS.  n nmiss min max nolabels ;
    var KEY DRG MDC YEAR DQTR POPCAT SEXCAT RACECAT ;
     title4 "CATEGORICAL VARIABLES AND RANGES OF VALUES";
run; quit;

proc Means data = OUTMSR.&OUTFILE_MEAS. n nmiss sum mean  nolabels  ;
     var TAPQ09;
    * OUTPUT OUT=STATS;
     title "PREVENTION QUALITY INDICATOR NUMERATORS (COUNT =SUM)";
run; quit; 


