*================ Program: PSI_PROV_OBSERVED.SAS ======================;
*
*   Title:  PROVIDER LEVEL OBSERVED RATES FOR AHRQ 
*                PATIENT SAFETY INDICATORS
*                
*  Description:
*     Calculates observed rates for provider level Patient Safety Indicators
*     using numerator and denominator output from PSI_ALL_MEASURES.sas.
*     output stratified by HOSPID, AGECAT, SEXCAT, PAYCAT and RACECAT.
*     variable created by this program is OPPSXX
*
*  VERSION: SAS QI v2018 (ICD-10 CM/PCS)
*  RELEASE DATE: JUNE 2018
*
*======================================================================;

*PATHNAME specifies the location of the PSI  folder which includes 
          Programs, SASdata, and Macros subfolders;
%LET PATHNAME= c:\pathname\PSI;                *<===USER MUST modify;

filename CONTROL "&PATHNAME.\Programs\PSI_ALL_CONTROL.SAS"; 

%INCLUDE CONTROL;

 title2 'PROGRAM: PSI_PROV_OBSERVED';
 title3 'AHRQ PATIENT SAFETY INDICATORS: CALCULATE OBSERVED PROVIDER LEVEL RATES';

* ------------------------------------------------------------------ ;
* --- PROVIDER LEVEL MEANS ON PSI_ALL_MEASURES OUTPUT DATA FILE  --- ;
* --- VARIABLES TPPSxx AND PPPSxx ARE CREATED IN MEASURES AND    --- ;
* --- ARE USED TO CREATE THE OPPSxx VARIABLES                    --- ;
* ------------------------------------------------------------------ ;
 
* ------------------------------------------------------------------ ;
* --- PATIENT SAFETY INDICATOR (PSI) NAMING CONVENTION:          --- ;
* --- THE FIRST LETTER IDENTIFIES THE PATIENT SAFETY             --- ;
* --- INDICATOR AS ONE OF THE FOLLOWING:                         --- ;
* ---           (T) NUMERATOR ("TOP") - FROM PSI_ALL_MEASURES    --- ;
* ---           (P) DENOMINATOR ("POP") - FROM PSI_ALL_MEASURES  --- ;
* ---           (O) OBSERVED RATES (T/P)                         --- ;
* --- THE SECOND LETTER IDENTIFIES THE PSI AS A PROVIDER (P)     --- ;
* --- LEVEL INDICATOR.  THE NEXT TWO CHARACTERS ARE ALWAYS 'PS'. --- ;
* --- THE LAST TWO DIGITS ARE THE INDICATOR NUMBER               --- ;
* ------------------------------------------------------------------ ;

 proc Summary data=OUTMSR.&OUTFILE_MEAS.;
   class  HOSPID AGECAT SEXCAT PAYCAT RACECAT;
      var    TPPS02-TPPS16 TPPS18 TPPS19;
   output out=&OUTFILE_PROVOBS.
        sum (TPPS02-TPPS04 TPPS04A TPPS04B TPPS04C TPPS04D TPPS04E TPPS05-TPPS14 TPPS14A TPPS14B TPPS15 TPPS16 TPPS18 TPPS19) = 
             TPPS02-TPPS04 TPPS04A TPPS04B TPPS04C TPPS04D TPPS04E TPPS05-TPPS14 TPPS14A TPPS14B TPPS15 TPPS16 TPPS18 TPPS19
        sum (PPPS02-PPPS04 PPPS04A PPPS04B PPPS04C PPPS04D PPPS04E PPPS05-PPPS14 PPPS14A PPPS14B PPPS15 PPPS16 PPPS18 PPPS19) = 
             PPPS02-PPPS04 PPPS04A PPPS04B PPPS04C PPPS04D PPPS04E PPPS05-PPPS14 PPPS14A PPPS14B PPPS15 PPPS16 PPPS18 PPPS19
        mean(TPPS02-TPPS04 TPPS04A TPPS04B TPPS04C TPPS04D TPPS04E TPPS05-TPPS16 TPPS18 TPPS19) = 
             OPPS02-OPPS04 OPPS04A OPPS04B OPPS04C OPPS04D OPPS04E OPPS05-OPPS16 OPPS18 OPPS19;
 run;

 proc Sort data=&OUTFILE_PROVOBS.;
   by HOSPID AGECAT SEXCAT PAYCAT RACECAT;
 run;

 data OUTPOBS.&OUTFILE_PROVOBS.;
   set &OUTFILE_PROVOBS. (where=(_TYPE_ &TYPELVLP)) ;

 %MACRO LBL;

 label
 TPPS02 = 'PSI 02 Death Rate in Low-Mortality Diagnosis Related Groups (DRGs) (Numerator)'
 TPPS03 = 'PSI 03 Pressure Ulcer Rate (Numerator)'
 TPPS04 = 'PSI 04 Death Rate among Surgical Inpatients with Serious Treatable Conditions (Numerator)'
 TPPS04A= 'PSI 04A Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04A: Deep Vein Thrombosis/Pulmonary Embolism (DVT/PE) (Numerator)'
 TPPS04B= 'PSI 04B Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04B: Pneumonia (Numerator)'
 TPPS04C= 'PSI 04C Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04C: Sepsis (Numerator)'
 TPPS04D= 'PSI 04D Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04D: Shock/Cardiac Arrest (Numerator)'
 TPPS04E= 'PSI 04E Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04E: Gastrointestinal (GI) Hemorrhage/Acute Ulcer (Numerator)'
 TPPS05 = 'PSI 05 Retained Surgical Item or Unretrieved Device Fragment Count (Numerator)'
 TPPS06 = 'PSI 06 Iatrogenic Pneumothorax Rate (Numerator)'
 TPPS07 = 'PSI 07 Central Venous Catheter-Related Blood Stream Infection Rate (Numerator)'
 TPPS08 = 'PSI 08 In Hospital Fall with Hip Fracture Rate (Numerator)'
 TPPS09 = 'PSI 09 Perioperative Hemorrhage or Hematoma Rate (Numerator)'
 TPPS10 = 'PSI 10 Postoperative Acute Kidney Injury Requiring Dialysis Rate (Numerator)'
 TPPS11 = 'PSI 11 Postoperative Respiratory Failure Rate (Numerator)'
 TPPS12 = 'PSI 12 Perioperative Pulmonary Embolism or Deep Vein Thrombosis Rate (Numerator)'
 TPPS13 = 'PSI 13 Postoperative Sepsis Rate (Numerator)'
 TPPS14 = 'PSI 14 Postoperative Wound Dehiscence Rate (Numerator)'
 TPPS14A= 'PSI 14A Postoperative Wound Dehiscence Rate Stratum 14A: Open Approach (Numerator)'
 TPPS14B= 'PSI 14B Postoperative Wound Dehiscence Rate Stratum 14B: Non-Open Approach (Numerator)'
 TPPS15 = 'PSI 15 Unrecognized Abdominopelvic Accidental Puncture or Laceration Rate (Numerator)'
 TPPS16 = 'PSI 16 Transfusion Reaction Count (Numerator)'
 TPPS18 = 'PSI 18 Obstetric Trauma Rate - Vaginal Delivery With Instrument (Numerator)'
 TPPS19 = 'PSI 19 Obstetric Trauma Rate - Vaginal Delivery Without Instrument (Numerator)'

 PPPS02 = 'PSI 02 Death Rate in Low-Mortality Diagnosis Related Groups (DRGs) (Pop)'
 PPPS03 = 'PSI 03 Pressure Ulcer Rate (Pop)'
 PPPS04 = 'PSI 04 Death Rate among Surgical Inpatients with Serious Treatable Conditions (Pop)'
 PPPS04A= 'PSI 04A Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04A: Deep Vein Thrombosis/Pulmonary Embolism (DVT/PE) (Pop)'
 PPPS04B= 'PSI 04B Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04B: Pneumonia (Pop)'
 PPPS04C= 'PSI 04C Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04C: Sepsis (Pop)'
 PPPS04D= 'PSI 04D Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04D: Shock/Cardiac Arrest (Pop)'
 PPPS04E= 'PSI 04E Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04E: Gastrointestinal (GI) Hemorrhage/Acute Ulcer (Pop)'
 PPPS05 = 'PSI 05 Retained Surgical Item or Unretrieved Device Fragment Count (Pop)'
 PPPS06 = 'PSI 06 Iatrogenic Pneumothorax Rate (Pop)'
 PPPS07 = 'PSI 07 Central Venous Catheter-Related Blood Stream Infection Rate (Pop)'
 PPPS08 = 'PSI 08 In Hospital Fall with Hip Fracture Rate (Pop)'
 PPPS09 = 'PSI 09 Perioperative Hemorrhage or Hematoma Rate (Pop)'
 PPPS10 = 'PSI 10 Postoperative Acute Kidney Injury Requiring Dialysis Rate (Pop)'
 PPPS11 = 'PSI 11 Postoperative Respiratory Failure Rate (Pop)'
 PPPS12 = 'PSI 12 Perioperative Pulmonary Embolism or Deep Vein Thrombosis Rate (Pop)'
 PPPS13 = 'PSI 13 Postoperative Sepsis Rate (Pop)'
 PPPS14 = 'PSI 14 Postoperative Wound Dehiscence Rate (Pop)'
 PPPS14A= 'PSI 14A Postoperative Wound Dehiscence Rate Stratum 14A: Open Approach (Pop)'
 PPPS14B= 'PSI 14B Postoperative Wound Dehiscence Rate Stratum 14B: Non-Open Approach (Pop)'
 PPPS15 = 'PSI 15 Unrecognized Abdominopelvic Accidental Puncture or Laceration Rate (Pop)'
 PPPS16 = 'PSI 16 Transfusion Reaction Count (Pop)'
 PPPS18 = 'PSI 18 Obstetric Trauma Rate - Vaginal Delivery With Instrument (Pop)'
 PPPS19 = 'PSI 19 Obstetric Trauma Rate - Vaginal Delivery Without Instrument (Pop)'

 OPPS02 = 'PSI 02 Death Rate in Low-Mortality Diagnosis Related Groups (DRGs) (Observed)'
 OPPS03 = 'PSI 03 Pressure Ulcer Rate (Observed)'
 OPPS04 = 'PSI 04 Death Rate among Surgical Inpatients with Serious Treatable Conditions (Observed)'
 OPPS04A= 'PSI 04A Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04A: Deep Vein Thrombosis/Pulmonary Embolism (DVT/PE) (Observed)'
 OPPS04B= 'PSI 04B Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04B: Pneumonia (Observed)'
 OPPS04C= 'PSI 04C Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04C: Sepsis (Observed)'
 OPPS04D= 'PSI 04D Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04D: Shock/Cardiac Arrest (Observed)'
 OPPS04E= 'PSI 04E Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04E: Gastrointestinal (GI) Hemorrhage/Acute Ulcer (Observed)'
 OPPS05 = 'PSI 05 Retained Surgical Item or Unretrieved Device Fragment Count (Observed)'
 OPPS06 = 'PSI 06 Iatrogenic Pneumothorax Rate (Observed)'
 OPPS07 = 'PSI 07 Central Venous Catheter-Related Blood Stream Infection Rate (Observed)'
 OPPS08 = 'PSI 08 In Hospital Fall with Hip Fracture Rate (Observed)'
 OPPS09 = 'PSI 09 Perioperative Hemorrhage or Hematoma Rate (Observed)'
 OPPS10 = 'PSI 10 Postoperative Acute Kidney Injury Requiring Dialysis Rate (Observed)'
 OPPS11 = 'PSI 11 Postoperative Respiratory Failure Rate (Observed)'
 OPPS12 = 'PSI 12 Perioperative Pulmonary Embolism or Deep Vein Thrombosis Rate (Observed)'
 OPPS13 = 'PSI 13 Postoperative Sepsis Rate (Observed)'
 OPPS14 = 'PSI 14 Postoperative Wound Dehiscence Rate (Observed)'
 OPPS15 = 'PSI 15 Unrecognized Abdominopelvic Accidental Puncture or Laceration Rate (Observed)'
 OPPS16 = 'PSI 16 Transfusion Reaction Count (Observed)'
 OPPS18 = 'PSI 18 Obstetric Trauma Rate - Vaginal Delivery With Instrument (Observed)'
 OPPS19 = 'PSI 19 Obstetric Trauma Rate - Vaginal Delivery Without Instrument (Observed)'
 _TYPE_ = 'STRATIFICATION LEVEL '
 ;

 * -------------------------------------------------------------- ;
 * --- RE-LABEL DAY DEPENDENT INDICATORS ------------------------ ;
 * -------------------------------------------------------------- ;
 %IF &PRDAY. = 0 %THEN %DO;
 label
   TPPS03 = 'PSI 03 Pressure Ulcer Rate-NO PRDAY (Numerator)'
   TPPS08 = 'PSI 08 In Hospital Fall with Hip Fracture Rate-NO PRDAY (Numerator)'
   TPPS09 = 'PSI 09 Perioperative Hemorrhage or Hematoma Rate-NO PRDAY (Numerator)'
   TPPS10 = 'PSI 10 Postoperative Acute Kidney Injury Requiring Dialysis Rate-NO PRDAY (Numerator)'
   TPPS11 = 'PSI 11 Postoperative Respiratory Failure Rate-NO PRDAY (Numerator)'
   TPPS12 = 'PSI 12 Perioperative Pulmonary Embolism or Deep Vein Thrombosis Rate-NO PRDAY (Numerator)'
   TPPS14 = 'PSI 14 Postoperative Wound Dehiscence Rate-NO PRDAY (Numerator)'

   PPPS03 = 'PSI 03 Pressure Ulcer Rate-NO PRDAY (Pop)'
   PPPS08 = 'PSI 08 In Hospital Fall with Hip Fracture Rate-NO PRDAY (Pop)'
   PPPS09 = 'PSI 09 Perioperative Hemorrhage or Hematoma Rate-NO PRDAY (Pop)'
   PPPS10 = 'PSI 10 Postoperative Acute Kidney Injury Requiring Dialysis Rate-NO PRDAY (Pop)'
   PPPS11 = 'PSI 11 Postoperative Respiratory Failure Rate-NO PRDAY (Pop)'
   PPPS12 = 'PSI 12 Perioperative Pulmonary Embolism or Deep Vein Thrombosis Rate-NO PRDAY (Pop)'
   PPPS14 = 'PSI 14 Postoperative Wound Dehiscence Rate-NO PRDAY (Pop)'

   OPPS03 = 'PSI 03 Pressure Ulcer Rate-NO PRDAY (Observed)'
   OPPS08 = 'PSI 08 In Hospital Fall with Hip Fracture Rate-NO PRDAY (Observed)'
   OPPS09 = 'PSI 09 Perioperative Hemorrhage or Hematoma Rate-NO PRDAY (Observed)'
   OPPS10 = 'PSI 10 Postoperative Acute Kidney Injury Requiring Dialysis Rate-NO PRDAY (Observed)'
   OPPS11 = 'PSI 11 Postoperative Respiratory Failure Rate-NO PRDAY (Observed)'
   OPPS12 = 'PSI 12 Perioperative Pulmonary Embolism or Deep Vein Thrombosis Rate-NO PRDAY (Observed)'
   OPPS14 = 'PSI 14 Postoperative Wound Dehiscence Rate-NO PRDAY (Observed)'
 ;
 %END;

 %MEND;

 %LBL;

 drop _FREQ_ ;

 run;

 * -------------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF PROVIDER OBSERVED MEANS FILE ------- ;
 * -------------------------------------------------------------- ;

 proc Contents data=OUTPOBS.&OUTFILE_PROVOBS. position;
 run;

 
***----- TO PRINT VARIABLE LABELS COMMENT (DELETE) "NOLABELS" FROM PROC MEANS STATEMENTS -------***;
proc Means data=OUTPOBS.&OUTFILE_PROVOBS. (where=(_TYPE_ IN (16))) n nmiss min max sum nolabels;
   var TPPS02-TPPS04 TPPS04A TPPS04B TPPS04C TPPS04D TPPS04E TPPS05-TPPS14 TPPS14A TPPS14B TPPS15 TPPS16 TPPS18 TPPS19;
   title  'SUMMARY OF PATIENT SAFETY PROVIDER LEVEL INDICATOR OVERALL NUMERATOR (SUM) WHEN _TYPE_=16';
run; quit;

proc Means data=OUTPOBS.&OUTFILE_PROVOBS. (where=(_TYPE_ IN (16))) n nmiss min max sum nolabels;
   var PPPS02-PPPS04 PPPS04A PPPS04B PPPS04C PPPS04D PPPS04E PPPS05-PPPS14 PPPS14A PPPS14B PPPS15 PPPS16 PPPS18 PPPS19;
   title  'SUMMARY OF PATIENT SAFETY PROVIDER LEVEL INDICATOR OVERALL DENOMINATOR (SUM) WHEN _TYPE_=16';
run; quit;

proc Means data=OUTPOBS.&OUTFILE_PROVOBS. (where=(_TYPE_ IN (16))) n nmiss min max mean nolabels;
   var OPPS02-OPPS04 OPPS04A OPPS04B OPPS04C OPPS04D OPPS04E OPPS05-OPPS16 OPPS18 OPPS19;
   title  'SUMMARY OF PATIENT SAFETY PROVIDER LEVEL INDICATOR AVERAGE RATES(MEAN) WHEN _TYPE_=16';
run; quit;

 * -------------------------------------------------------- ;
 * --- PRINT PROVIDER OBSERVED MEANS FILE TO SAS OUTPUT --- ;
 * -------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(PS,TEXT);

 proc  Print data=OUTPOBS.&OUTFILE_PROVOBS. label split='*';
 var   HOSPID AGECAT SEXCAT PAYCAT RACECAT TPPS&PS. PPPS&PS. OPPS&PS. ;
 label HOSPID  = "HOSPID"
       AGECAT  = "AGECAT"
       SEXCAT  = "SEXCAT"
       PAYCAT  = "PAYCAT"
       RACECAT = "RACECAT"
       TPPS&PS.   = "TPPS&PS.*(Numerator)"
       PPPS&PS.   = "PPPS&PS.*(Denominator)"
       OPPS&PS.   = "OPPS&PS.*(Observed)"
       ;
 format AGECAT AGECAT.
        SEXCAT SEXCAT.
        PAYCAT PAYCAT.
        RACECAT RACECAT.
        TPPS&PS. PPPS&PS. 13.0 OPPS&PS. 8.6;
 title4 "Indicator &PS.: &TEXT";
 run;

 %MEND PRT;

 %PRT(02,Death Rate in Low-Mortality Diagnosis Related Groups (DRGs));
 %IF &PRDAY. = 1 %THEN %DO;
     %PRT(03,Pressure Ulcer Rate);
 %END;
 %ELSE %DO;
     %PRT(03,Pressure Ulcer Rate-NO PRDAY);
 %END;
 %PRT(04,Death Rate among Surgical Inpatients with Serious Treatable Conditions);
 %PRT(04A,Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04A: Deep Vein Thrombosis/Pulmonary Embolism (DVT/PE));
 %PRT(04B,Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04B: Pneumonia);
 %PRT(04C,Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04C: Sepsis);
 %PRT(04D,Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04D: Shock/Cardiac Arrest);
 %PRT(04E,Death Rate among Surgical Inpatients with Serious Treatable Conditions Stratum 04E: Gastrointestinal (GI) Hemorrhage/Acute Ulcer);
 %PRT(05,Retained Surgical Item or Unretrieved Device Fragment Count);
 %PRT(06,Iatrogenic Pneumothorax Rate);
 %PRT(07,Central Venous Catheter-Related Blood Stream Infection Rate);
 %IF &PRDAY. = 1 %THEN %DO;
     %PRT(08,In Hospital Fall with Hip Fracture Rate);
     %PRT(09,Perioperative Hemorrhage or Hematoma Rate);
     %PRT(10,Postoperative Acute Kidney Injury Requiring Dialysis Rate);
     %PRT(11,Postoperative Respiratory Failure Rate);
     %PRT(12,Perioperative Pulmonary Embolism or Deep Vein Thrombosis Rate);
 %END;
 %ELSE %DO;
     %PRT(08,In Hospital Fall with Hip Fracture Rate-NO PRDAY);
     %PRT(09,Perioperative Hemorrhage or Hematoma Rate-NO PRDAY);
     %PRT(10,Postoperative Acute Kidney Injury Requiring Dialysis Rate-NO PRDAY);
      %PRT(11,Postoperative Respiratory Failure Rate-NO PRDAY);
     %PRT(12,Perioperative Pulmonary Embolism or Deep Vein Thrombosis Rate-NO PRDAY);
 %END;
 %PRT(13,Postoperative Sepsis Rate);
 %IF &PRDAY. = 1 %THEN %DO;
     %PRT(14,Postoperative Wound Dehiscence Rate);
 %END;
 %ELSE %DO;
     %PRT(14,Postoperative Wound Dehiscence Rate-NO PRDAY);
 %END;
 %PRT(15,Unrecognized Abdominopelvic Accidental Puncture or Laceration Rate);
 %PRT(16,Transfusion Reaction Count);
 %PRT(18,Obstetric Trauma Rate - Vaginal Delivery With Instrument);
 %PRT(19,Obstetric Trauma Rate - Vaginal Delivery Without Instrument);

 %END;

 %MEND PRT2;

 %PRT2;


 * -------------------------------------------------------------- ;
 * --- WRITE SAS OUTPUT DATA SET TO COMMA-DELIMITED TEXT FILE --- ;
 * --- FOR EXPORT INTO SPREADSHEETS                          ---- ;
 * -------------------------------------------------------------- ;

 %MACRO TEXTP1;
 %if &TXTPOBS. = 1  %then %do;
 data _NULL_;
 set OUTPOBS.&OUTFILE_PROVOBS.;
 file PSTXTPOB lrecl=2000 ;
 if _N_=1 then do;

  put "Hosp Id" "," "Age" "," "Sex" "," "Payer" "," "Race" "," "Type" ","
 "TPPS02" "," "TPPS03" "," "TPPS04" "," "TPPS04A" "," "TPPS04B" "," "TPPS04C" "," "TPPS04D" "," "TPPS04E" ","
 "TPPS05" "," "TPPS06" "," "TPPS07" "," "TPPS08" ","
 "TPPS09" "," "TPPS10" "," "TPPS11" "," "TPPS12" ","
 "TPPS13" "," "TPPS14" "," "TPPS14A" "," "TPPS14B" "," "TPPS15" "," "TPPS16" ","
 "TPPS18" "," "TPPS19" "," 
 "PPPS02" "," "PPPS03" "," "PPPS04" "," "PPPS04A" "," "PPPS04B" "," "PPPS04C" "," "PPPS04D" "," "PPPS04E" ","
 "PPPS05" "," "PPPS06" "," "PPPS07" "," "PPPS08" ","
 "PPPS09" "," "PPPS10" "," "PPPS11" "," "PPPS12" ","
 "PPPS13" "," "PPPS14" "," "PPPS14A" "," "PPPS14B" "," "PPPS15" "," "PPPS16" ","
 "PPPS18" "," "PPPS19" "," 
 "OPPS02" "," "OPPS03" "," "OPPS04" "," "OPPS04A" "," "OPPS04B" "," "OPPS04C" "," "OPPS04D" "," "OPPS04E" ","
 "OPPS05" "," "OPPS06" "," "OPPS07" "," "OPPS08" ","
 "OPPS09" "," "OPPS10" "," "OPPS11" "," "OPPS12" ","
 "OPPS13" "," "OPPS14" "," "OPPS15" "," "OPPS16" ","
 "OPPS18" "," "OPPS19" 
 ;
 end;
 
 put HOSPID 13. "," AGECAT 3. "," SEXCAT 3. "," PAYCAT 3. "," RACECAT 3. "," _TYPE_ 2.  ","
 (TPPS02-TPPS04 TPPS04A TPPS04B TPPS04C TPPS04D TPPS04E TPPS05-TPPS14 TPPS14A TPPS14B TPPS15 TPPS16 TPPS18 TPPS19) (7.0 ",")
  ","
 (PPPS02-PPPS04 PPPS04A PPPS04B PPPS04C PPPS04D PPPS04E PPPS05-PPPS14 PPPS14A PPPS14B PPPS15 PPPS16 PPPS18 PPPS19) (13.2 ",")
 ","
 (OPPS02-OPPS04 OPPS04A OPPS04B OPPS04C OPPS04D OPPS04E OPPS05-OPPS16 OPPS18 OPPS19) (12.10 ",")
 ;
 run;

 %END;

 %MEND TEXTP1;

 %TEXTP1;
