*=================== PROGRAM: PSI17_ALL_MEASURES.SAS ===========================;
*
*  DESCRIPTION: ASSIGNS NUMERATOR AND DENOMINATOR FLAGS FOR PSI 17, 
*               BIRTH TRAUMA RATE  INJURY TO NEONATE. 
*               THIS INDICATOR IS ALSO INCLUDED IN THE PEDIATRIC  
*               QUALITY INDICATOR MODULE.
*
*  VERSION: SAS QI v2018 (ICD-10 CM/PCS)
*  RELEASE DATE: JUNE 2018
*
*  USER NOTE1:  The PSI17_ALL_FORMATS.SAS program must be run BEFORE
*               running this program.

*  USER NOTE2:  The AHRQ QI software does not support the calculation of  
*               weighted estimates and standard errors using complex 
*               sampling designs. 
*
* ============================================================================;
*PATHNAME specifies the location of the PSI17 folder which includes 
          Programs, SASdata, and Macros subfolders;
%LET PATHNAME=C:\Pathname\PSI17;                    *<==USER MUST modify;

filename CONTROL "&PATHNAME.\Programs\PSI17_ALL_CONTROL.SAS";

%INCLUDE CONTROL;

 title2 'PROGRAM: PSI17_ALL_MEASURES';
 title3 'AHRQ PATIENT SAFETY INDICATORS: ASSIGN PSI 17 TO INPATIENT DATA';


 * -------------------------------------------------------------- ;
 * --- CREATE A PERMANENT DATASET CONTAINING ALL RECORDS THAT --- ; 
 * --- WILL NOT BE INCLUDED IN ANALYSIS BECAUSE KEY VARIABLE  --- ;
 * --- VALUES ARE MISSING.                   			      --- ;
 * -------------------------------------------------------------- ;

 data   OUTMSR.&DELFILE.
 	(keep=KEY HOSPID SEX AGE DX1 MDC YEAR DQTR);
 set 	INMSR.&DISCHARGE.;
 if (AGE lt 0) or (AGE ge 18 or MDC IN (14)) or (SEX le 0) or 
	(DX1 IN (' ')) or (DQTR le .Z) or (YEAR le .Z);
 run;
 
  *--- Load standard diagnosis and procedure macros ---* ;
 %include Maclib(PSI17_Dx_Px_Macros.sas) ;

 * ---------------------------------------------------------------- ;
 * --- PATIENT SAFETY INDICATOR (PSI) NAMING CONVENTION:        --- ;
 * --- THE FIRST LETTER IDENTIFIES THE PATIENT SAFETY INDICATOR --- ;
 * --- AS NUMERATOR, 'T' ("TOP"). THE SECOND LETTER IDENTIFIES  --- ;
 * --- THE TYPE OF INDICATOR WITH 'P' FOR PROVIDER LEVEL. THE   --- ;
 * --- NEXT TWO CHARACTERS ARE 'PS'. THE LAST TWO DIGITS ARE    --- ;
 * --- 17 FOR INDICATOR PSI 17.                         	    --- ;
 * ---------------------------------------------------------------- ;
 data   OUTMSR.&OUTFILE_MEAS. 
    (keep=KEY HOSPID DRG MDC YEAR DQTR 
          PAGECAT AGEDCAT BWHTCAT SEXCAT RACECAT PAYCAT
          TPPS17);
 set   INMSR.&DISCHARGE. 
     (keep=KEY HOSPID DRG MDC SEX AGE AGEDAY 
           RACE YEAR DQTR PAY1 POINTOFORIGINUB04 ATYPE
           DX1-DX&NDX.);

 
 * ----------------------------------------------------------------- ;
 * --- DELETE NON-PEDIATRIC RECORDS AND RECORDS WITH MISSING VALUES  ;
 * ----------------------------------------------------------------- ;
 if SEX le 0 then delete;
 if AGE lt 0 then delete;
 if AGE ge 18 or MDC in (14) then delete;
 if compress(DX1) in ('') then delete;
 if DQTR le .Z then delete;
 if YEAR le .Z then delete;

 * -------------------------------------------------------------- ;
 * --- DEFINE ICD-10-CM VERSION --------------------------------- ;
 * -------------------------------------------------------------- ;
 attrib ICDVER length=3
   label='ICD-10-CM VERSION';

 ICDVER = 0;
 if (YEAR in (2015) and DQTR in (4))          then ICDVER = 33;
 else if (YEAR in (2016) and DQTR in (1,2,3)) then ICDVER = 33;
 else if (YEAR in (2016) and DQTR in (4))     then ICDVER = 34;
 else if (YEAR in (2017) and DQTR in (1,2,3)) then ICDVER = 34;
 else if (YEAR in (2017) and DQTR in (4))     then ICDVER = 35;
 else if (YEAR in (2018) and DQTR in (1,2,3)) then ICDVER = 35;
 else ICDVER = 35; *Defaults to last version for discharges outside coding updates.;
 
 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: PAYER CATEGORY ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib PAYCAT length=3
   label='PATIENT PRIMARY PAYER';

 select (PAY1);
   when (1)  PAYCAT = 1;
   when (2)  PAYCAT = 2;
   when (3)  PAYCAT = 3;
   when (4)  PAYCAT = 4;
   when (5)  PAYCAT = 5;
   otherwise PAYCAT = 6;
 end; 
    

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: RACE CATEGORY ------------------------- ;
 * -------------------------------------------------------------- ;
 attrib RACECAT length=3
   label='PATIENT RACE/ETHNICITY';

 select (RACE);
   when (1)  RACECAT = 1;
   when (2)  RACECAT = 2;
   when (3)  RACECAT = 3;
   when (4)  RACECAT = 4;
   when (5)  RACECAT = 5;
   otherwise RACECAT = 6;
 end; 


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: AGE CATEGORY -------------------------- ;
 * -------------------------------------------------------------- ;
 attrib PAGECAT length=3
   label='PATIENT AGE';

 select;
   when (0  <= AGE <  1)  PAGECAT = 1;
   when (1  <= AGE <  3)  PAGECAT = 2;
   when (3  <= AGE <  6)  PAGECAT = 3;
   when (6  <= AGE < 13)  PAGECAT = 4;
   when (13 <= AGE < 18)  PAGECAT = 5;
   otherwise PAGECAT = 0;
 end;


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: AGEDAY CATEGORY ----------------------- ;
 * -------------------------------------------------------------- ;
 attrib AGEDCAT length=3
   label='PATIENT AGE IN DAYS';

 select;
   when (      AGEDAY <   0)  AGEDCAT = 0;
   when (0  <= AGEDAY <= 28)  AGEDCAT = 1;
   when (29 <= AGEDAY <= 60)  AGEDCAT = 2;
   when (61 <= AGEDAY <= 90)  AGEDCAT = 3;
   when (91 <= AGEDAY      )  AGEDCAT = 4;
   otherwise AGEDCAT = 0;
 end;


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: SEX CATEGORY -------------------------- ;
 * -------------------------------------------------------------- ;
 attrib SEXCAT length=3
   label='PATIENT SEX';

 select (SEX);
   when (1)  SEXCAT = 1;
   when (2)  SEXCAT = 2;
   otherwise SEXCAT = 0;
 end; 


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: BIRTH WEIGHT CATEGORY ----------------- ;
 * -------------------------------------------------------------- ;
 attrib BWHTCAT length=3
   label='PATIENT BIRTHWEIGHT';

 %MACRO BWHT;

 BWHTCAT = 0;
 %DO I = 1 %TO &NDX.;
    if put(DX&I.,$LW500G.)  = '1'      then BWHTCAT = 1;
    else if put(DX&I.,$LW750G.)  = '1' and (BWHTCAT = 0 or  BWHTCAT > 2) then BWHTCAT = 2;
    else if put(DX&I.,$LW1000G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 3) then BWHTCAT = 3;
    else if put(DX&I.,$LW1250G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 4) then BWHTCAT = 4;
    else if put(DX&I.,$LW1500G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 5) then BWHTCAT = 5;
    else if put(DX&I.,$LW1750G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 6) then BWHTCAT = 6;
    else if put(DX&I.,$LW2000G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 7) then BWHTCAT = 7;
    else if put(DX&I.,$LW2500G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 8) then BWHTCAT = 8;
 %END;
 
 %MEND;

 %BWHT;

 * -------------------------------------------------------------- ;
 * --- DEFINE PROVIDER LEVEL INDICATORS ------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO LBL;

 attrib
 TPPS17 length=8
   label='PSI 17 Birth Trauma Rate - Injury to Neonate (Numerator)'
;

 %MEND;

 %LBL;


 * -------------------------------------------------------------- ;
 * --- IDENTIFY NEONATES AND NEWBORNS --------------------------- ;
 * -------------------------------------------------------------- ;

   NEONATE = 0;
   if 0 <= AGEDAY <= 28 then NEONATE = 1;
   else if AGEDAY le .Z and AGE = 0 then do;
      if ATYPE IN (4) or %MDX($LIVEBND.)
      then NEONATE = 1;
   end;

   NEWBORN = 0;
   if NEONATE then do;
      if %MDX($LIVEBND.) and NOT AGEDAY > 0 then NEWBORN = 1;
      else if ATYPE IN (4) and 
              ((AGEDAY = 0 and NOT %MDX($LIVEB2D.)) or
               POINTOFORIGINUB04 IN ('5'))
      then NEWBORN = 1;
   end;
 

 * --------------------------------------------------------- ;
 * ---   PSI 17 : BIRTH TRAUMA RATE - INJURY TO NEONATE  --- ;
 * --------------------------------------------------------- ;

   if NEWBORN then do;

      TPPS17 = 0;
      if %MDX($BIRTHID.) then TPPS17 = 1;

   *** Exclude Birth weight less than 2000g;
      if %MDX($PRETEID.) then TPPS17 = .;
	  
   *** Exclude Osteogenesis imperfecta;
      if %MDX($OSTEOID.) then TPPS17 = .;

   end;


run;

proc Means DATA=OUTMSR.&OUTFILE_MEAS. N NMISS MIN MAX MEAN SUM NOLABELS;
title4 'PSI 17 MEASURE OUTPUT SUMMARY STATISTICS';
run;

proc Contents DATA=OUTMSR.&OUTFILE_MEAS. POSITION;
title5 'PSI 17 MEASURE OUTPUT CONTENTS';
run;

proc Print DATA=OUTMSR.&OUTFILE_MEAS. (OBS=24);
  title6 "FIRST 24 RECORDS IN OUTPUT DATA SET &OUTFILE_MEAS.";
run;
